#[non_exhaustive]pub enum ConfigError {
FrequencyTooLow,
FrequencyTooHigh,
}Expand description
SPI config error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FrequencyTooLow
The requested frequency is too low to be represented by the hardware.
FrequencyTooHigh
The requested frequency is too high to be represented by the hardware.